package com.fs.his.service;

import java.util.ArrayList;
import java.util.List;
import com.fs.his.domain.FsExportTask;
import com.fs.his.param.FsStoreOrderParam;
import com.fs.his.param.FsStorePaymentParam;

/**
 * 导出任务Service接口
 *
 * @author fs
 * @date 2024-11-19
 */
public interface IFsExportTaskService
{
    /**
     * 查询导出任务
     *
     * @param taskId 导出任务主键
     * @return 导出任务
     */
    public FsExportTask selectFsExportTaskByTaskId(Long taskId);

    /**
     * 查询导出任务列表
     *
     * @param fsExportTask 导出任务
     * @return 导出任务集合
     */
    public List<FsExportTask> selectFsExportTaskList(FsExportTask fsExportTask);

    /**
     * 新增导出任务
     *
     * @param fsExportTask 导出任务
     * @return 结果
     */
    public int insertFsExportTask(FsExportTask fsExportTask);

    /**
     * 修改导出任务
     *
     * @param fsExportTask 导出任务
     * @return 结果
     */
    public int updateFsExportTask(FsExportTask fsExportTask);

    /**
     * 批量删除导出任务
     *
     * @param taskIds 需要删除的导出任务主键集合
     * @return 结果
     */
    public int deleteFsExportTaskByTaskIds(Long[] taskIds);

    /**
     * 删除导出任务信息
     *
     * @param taskId 导出任务主键
     * @return 结果
     */
    public int deleteFsExportTaskByTaskId(Long taskId);

    Integer isExportType1( Long userId);

    public void exportStore1Data(FsStoreOrderParam param, boolean isCheckPhone, boolean isCheckAddress,ArrayList<String>filter);


    public void exportStoreData(FsStoreOrderParam fsStoreOrder);

    void exportStorePaymentData(FsStorePaymentParam fsStorePayment);

    Integer isExportType2(Long userId);
}
